==> conf_ini_g-2024.3-py3-none-any.whl: conf_ini_g/phase/typed/parameter/unit.py <==
# Copyright CNRS/Inria/UniCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from pathlib import Path as path_t
from typing import Any, Sequence


def ConvertedValue(
    value: Any, conversion_factor: int | float, /
) -> tuple[Any, list[str]]:
    """"""
    unconverted_values = []

    if _ValueIsNotUnitCompatible(value):
        converted = value
    elif isinstance(value, (int, float)):
        converted = conversion_factor * value
    elif isinstance(value, Sequence):
        converted = []
        for element in value:
            converted_elm, unconverted_elm = ConvertedValue(element, conversion_factor)
            converted.append(converted_elm)
            unconverted_values.extend(unconverted_elm)
        converted = tuple(converted)
    else:
        converted = value
        unconverted_values.append(str(value))

    return converted, unconverted_values


def _ValueIsNotUnitCompatible(value: Any, /) -> bool:
    """"""
    return (
        (value is None)
        or isinstance(value, bool)
        or isinstance(value, str)
        or isinstance(value, path_t)
    )

==> conf_ini_g-2024.8-py3-none-any.whl: conf_ini_g/phase/typed/parameter/unit.py <==
# Copyright CNRS/Inria/UniCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import typing as h
from pathlib import Path as path_t


def ConvertedValue(
    value: h.Any, conversion_factor: int | float, /
) -> tuple[h.Any, list[str]]:
    """"""
    unconverted_values = []

    if _ValueIsNotUnitCompatible(value):
        converted = value
    elif isinstance(value, (int, float)):
        converted = conversion_factor * value
    elif isinstance(value, h.Sequence):
        converted = []
        for element in value:
            converted_elm, unconverted_elm = ConvertedValue(element, conversion_factor)
            converted.append(converted_elm)
            unconverted_values.extend(unconverted_elm)
        converted = tuple(converted)
    else:
        converted = value
        unconverted_values.append(str(value))

    return converted, unconverted_values


def _ValueIsNotUnitCompatible(value: h.Any, /) -> bool:
    """"""
    return (
        (value is None)
        or isinstance(value, bool)
        or isinstance(value, str)
        or isinstance(value, path_t)
    )
